@@ -85,6 +85,10 @@ class Feature(BaseFeature):
         """
         Use this in configure_settings, to append new INSTALLED_APPS.
         """
+
+        if isinstance(apps, basestring):
+            apps = (apps,)
+
         for app in apps:
             if app not in self.settings.INSTALLED_APPS:
                 self.settings.INSTALLED_APPS += (app,)
@@ -93,6 +97,10 @@ class Feature(BaseFeature):
         """
         Use this in configure_settings, to append new middleware classes.
         """
+
+        if isinstance(classes, basestring):
+            classes = (classes,)
+
         for classname in classes:
             if classname not in self.settings.MIDDLEWARE_CLASSES:
                 self.settings.MIDDLEWARE_CLASSES += (classname,)
@@ -101,6 +109,9 @@ class Feature(BaseFeature):
         """
         Use this in configure_settings, to append new template processors.
         """
+        if isinstance(processors, basestring):
+            processors = (processors,)
+
         for classname in processors:
             if classname not in self.settings.TEMPLATE_CONTEXT_PROCESSORS:
                 self.settings.TEMPLATE_CONTEXT_PROCESSORS += (classname,)
