@@ -44,7 +44,7 @@ class CratisConfig(Configuration):
         for feature in cls.FEATURES:
 
             feature.set_settings(cls)
-            feature.do_load(loaded_features)
+            feature.on_load(loaded_features)
             loaded_features.append(type(feature))
 
 
